# {{ app_name }} | Todo and links list


## TODO

1. **// [ ] TODO: Example todo**
    * Describe the todo.
    <br />


## BUG FIXES

1. **// [ ] FIXME: Example to fix**
    * Describe the bug.
    <br />


## IMPROVEMENTS

### Documentation

1. **// [ ] TODO: Whatever to improve**
  * Describe and give examples.
    ```python
    print('Also code is allowed in md.')
    ```
    <br/>
